Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Logger ¶
Logger is an Fx event logger that logs events to log/slog.
func (*Logger) UseErrorLevel ¶
UseErrorLevel sets the level of error logs emitted by Fx to level.
func (*Logger) UseLogLevel ¶
UseLogLevel sets the level of non-error logs emitted by Fx to level.
Click to show internal directories.
Click to hide internal directories.